==> jc-1.4.0.tar.gz: polyglot/ext/jl/types/InitializerInstance__5fc.h <==
// public class polyglot.ext.jl.types.InitializerInstance_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6f73ec060d6cd1f1 polyglot_ext_jl_types_InitializerInstance__5fc
// @dep_class d130bd574566704f polyglot_ext_jl_types_TypeObject__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_types_TypeObject__5fc

#include "polyglot/ext/jl/types/TypeObject__5fc.h"

#ifndef _JC_polyglot_ext_jl_types_InitializerInstance__5fc_H_
#define _JC_polyglot_ext_jl_types_InitializerInstance__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_Flags$object;
struct _jc_polyglot_types_InitializerInstance$object;
struct _jc_polyglot_types_ReferenceType$object;
struct _jc_polyglot_types_TypeObject$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
extern void _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$_init$7d1c67b8be86a812(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, struct _jc_polyglot_types_Flags$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$container$f4cdd95bedc01213(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$container$84763addf78e0bed(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *);
extern jboolean _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$equalsImpl$8b26529c5bce72f0(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *);
extern struct _jc_polyglot_types_Flags$object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$flags$bdfb01ac8f620c5e(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$flags$fec41a7dcb6d8b9f(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_polyglot_types_Flags$object *);
extern jint _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
extern jboolean _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$isCanonical$a799dea5db41ebc5(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$container$f4cdd95bedc01213;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$container$84763addf78e0bed;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$equalsImpl$8b26529c5bce72f0;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$flags$bdfb01ac8f620c5e;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$flags$fec41a7dcb6d8b9f;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$isCanonical$a799dea5db41ebc5;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods {
	struct _jc_object	*(*container$f4cdd95bedc01213)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
	struct _jc_object	*(*container$84763addf78e0bed)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *);
	jboolean	(*equalsImpl$8b26529c5bce72f0)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *);
	struct _jc_polyglot_types_Flags$object	*(*flags$bdfb01ac8f620c5e)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
	struct _jc_object	*(*flags$fec41a7dcb6d8b9f)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_polyglot_types_Flags$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
	jboolean	(*isCanonical$a799dea5db41ebc5)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeObject__5fc$vmethods	polyglot_ext_jl_types_TypeObject__5fc;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods	polyglot_ext_jl_types_InitializerInstance__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs {
	struct _jc_object	*container;
	struct _jc_polyglot_types_Flags$object	*flags;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs {
    _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs	polyglot_ext_jl_types_InitializerInstance__5fc;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_refs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs	polyglot_ext_jl_types_InitializerInstance__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object {
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype _jc_polyglot_ext_jl_types_InitializerInstance__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_InitializerInstance__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_InitializerInstance__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_InitializerInstance__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/types/InitializerInstance__5fc.h <==
// public class polyglot.ext.jl.types.InitializerInstance_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6f73ec060d6cd1f1 polyglot_ext_jl_types_InitializerInstance__5fc
// @dep_class d130bd574566704f polyglot_ext_jl_types_TypeObject__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_types_TypeObject__5fc

#include "polyglot/ext/jl/types/TypeObject__5fc.h"

#ifndef _JC_polyglot_ext_jl_types_InitializerInstance__5fc_H_
#define _JC_polyglot_ext_jl_types_InitializerInstance__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_Flags$object;
struct _jc_polyglot_types_InitializerInstance$object;
struct _jc_polyglot_types_ReferenceType$object;
struct _jc_polyglot_types_TypeObject$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$_init$7d1c67b8be86a812(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, struct _jc_polyglot_types_Flags$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$container$f4cdd95bedc01213(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$container$84763addf78e0bed(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$equalsImpl$8b26529c5bce72f0(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_types_Flags$object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$flags$bdfb01ac8f620c5e(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$flags$fec41a7dcb6d8b9f(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_polyglot_types_Flags$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$isCanonical$a799dea5db41ebc5(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_InitializerInstance__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$container$f4cdd95bedc01213;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$container$84763addf78e0bed;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$equalsImpl$8b26529c5bce72f0;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$flags$bdfb01ac8f620c5e;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$flags$fec41a7dcb6d8b9f;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$isCanonical$a799dea5db41ebc5;
extern _jc_method _jc_polyglot_ext_jl_types_InitializerInstance__5fc$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods {
	struct _jc_object	*(*container$f4cdd95bedc01213)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*container$84763addf78e0bed)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equalsImpl$8b26529c5bce72f0)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_types_Flags$object	*(*flags$bdfb01ac8f620c5e)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*flags$fec41a7dcb6d8b9f)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *, struct _jc_polyglot_types_Flags$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
	jboolean	(*isCanonical$a799dea5db41ebc5)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeObject__5fc$vmethods	polyglot_ext_jl_types_TypeObject__5fc;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vmethods	polyglot_ext_jl_types_InitializerInstance__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs {
	struct _jc_object	*container;
	struct _jc_polyglot_types_Flags$object	*flags;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs {
    _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_refs	polyglot_ext_jl_types_InitializerInstance__5fc;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_refs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_polyglot_ext_jl_types_InitializerInstance__5fc$sub_nonrefs	polyglot_ext_jl_types_InitializerInstance__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_InitializerInstance__5fc$object {
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_InitializerInstance__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_InitializerInstance__5fc$vtype _jc_polyglot_ext_jl_types_InitializerInstance__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_InitializerInstance__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_InitializerInstance__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_InitializerInstance__5fc_H_ */
